﻿using System;
using System.Collections.ObjectModel;
using System.IO;
using System.Net;
using System.Windows;
using System.Xml.Linq;
using Delay;
using Microsoft.Phone.Controls;

namespace WebBrowserExtensionsWP
{
    public partial class MainPage : PhoneApplicationPage
    {
        public string FeedUriString { get; private set; }

        public ObservableCollection<Post> Posts { get; private set; }

        public MainPage()
        {
            InitializeComponent();
            FeedUriString = "http://blogs.msdn.com/b/delay/rss.aspx";
            Posts = new ObservableCollection<Post>();
            DataContext = this;
            var webClient = new WebClient();
            webClient.DownloadStringCompleted += new DownloadStringCompletedEventHandler(WebClient_DownloadStringCompleted);
            webClient.DownloadStringAsync(new Uri(FeedUriString));
        }

        private void WebClient_DownloadStringCompleted(object sender, DownloadStringCompletedEventArgs e)
        {
            try
            {
                using (var reader = new StringReader(e.Result))
                {
                    var feed = XElement.Load(reader);
                    foreach (var item in feed.Element("channel").Elements("item"))
                    {
                        Posts.Add(new Post(item.Element("title").Value, item.Element("description").Value));
                    }
                }
            }
            catch
            {
                Posts.Add(new Post("Sample Title 1", "Sample description 1."));
                Posts.Add(new Post("Sample Title 2", "<b>Sample</b> <i>description</i> <u>2</u>."));
            }
        }

        private void Button_Click(object sender, RoutedEventArgs e)
        {
            NavigationService.Navigate(new Uri("/SecondaryPage.xaml", UriKind.Relative));
        }

        private void WebBrowser_Loaded(object sender, RoutedEventArgs e)
        {
            var browser = sender as WebBrowser;
            if (null != browser)
            {
                var stringSource = browser.GetValue(WebBrowserExtensions.StringSourceProperty);
                if (null != stringSource)
                {
                    // "Bounce" the binding to work around a Windows Phone 7 bug where the WebBrowser
                    // loses its content when navigated away from/back to in the standard manner.
                    var bindingExpression = browser.GetBindingExpression(WebBrowserExtensions.StringSourceProperty);
                    browser.ClearValue(WebBrowserExtensions.StringSourceProperty);
                    if ((null != bindingExpression) && (null != bindingExpression.ParentBinding))
                    {
                        browser.SetBinding(WebBrowserExtensions.StringSourceProperty, bindingExpression.ParentBinding);
                    }
                    else
                    {
                        browser.SetValue(WebBrowserExtensions.StringSourceProperty, stringSource);
                    }
                }
            }
        }
    }

    public class Post
    {
        public string Title { get; private set; }
        public string Description { get; private set; }
        public Post(string title, string description)
        {
            Title = title;
            Description = description;
        }
    }
}
