﻿using System;
using System.Collections.ObjectModel;
using System.IO;
using System.Net;
using System.Windows;
using System.Xml.Linq;

namespace WebBrowserExtensionsWPF
{
    public partial class MainWindow : Window
    {
        public string FeedUriString { get; private set; }

        public ObservableCollection<Post> Posts { get; private set; }

        public MainWindow()
        {
            InitializeComponent();
            FeedUriString = "http://blogs.msdn.com/b/delay/rss.aspx";
            Posts = new ObservableCollection<Post>();
            DataContext = this;
            var webClient = new WebClient();
            webClient.DownloadStringCompleted += new DownloadStringCompletedEventHandler(WebClient_DownloadStringCompleted);
            webClient.DownloadStringAsync(new Uri(FeedUriString));
        }

        private void WebClient_DownloadStringCompleted(object sender, DownloadStringCompletedEventArgs e)
        {
            try
            {
                using (var reader = new StringReader(e.Result))
                {
                    var feed = XElement.Load(reader);
                    foreach (var item in feed.Element("channel").Elements("item"))
                    {
                        Posts.Add(new Post(item.Element("title").Value, item.Element("description").Value));
                    }
                }
            }
            catch
            {
                Posts.Add(new Post("Sample Title 1", "Sample description 1."));
                Posts.Add(new Post("Sample Title 2", "<b>Sample</b> <i>description</i> <u>2</u>."));
            }
        }
    }

    public class Post
    {
        public string Title { get; private set; }
        public string Description { get; private set; }
        public Post(string title, string description)
        {
            Title = title;
            Description = description;
        }
    }
}
